# remirepo spec file for php-pecl-oci8
#
# Copyright (c) 2014-2024 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%{?scl:          %scl_package         php-pecl-oci8}
%{!?scl:         %global _root_prefix %{_prefix}}

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  oci8
%global ini_name   40-%{pecl_name}.ini
%global sources    %{pecl_name}-%{version}
%global _configure ../%{sources}/configure

%ifarch aarch64
%global oraclever 19.23
%global oraclemax 20
%global oraclelib 19.1
%global oracledir 19.23
%else
%global oraclever 23.5
%global oraclemax 24
%global oraclelib 23.1
%global oracledir 23
%endif
%global with_dtrace 1


Summary:        Extension for Oracle Database
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
Version:        3.4.0
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}

License:        PHP-3.01
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{sources}.tgz

BuildRequires:  %{?scl_prefix}php-devel >= 8.2
BuildRequires:  %{?scl_prefix}php-pear
%if %{with_dtrace}
BuildRequires:  systemtap-sdt-devel
%endif
%ifarch aarch64
BuildRequires:  oracle-instantclient%{oraclever}-devel
# Should requires libclntsh.so.19.1()(aarch-64), but it's not provided by Oracle RPM.
Requires:       libclntsh.so.%{oraclelib}
AutoReq:        0
%else
BuildRequires: (oracle-instantclient-devel >= %{oraclever} with oracle-instantclient-devel < %{oraclemax})
%endif

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
# as we obsolete php-oci8 which provides both oci8 and pdo_oci extensions
Recommends:     %{?scl_prefix}php-pecl-pdo-oci

%if "%{php_version}" > "8.4"
Obsoletes:      %{?scl_prefix}php-%{pecl_name}               < 8.4
%else
Conflicts:      %{?scl_prefix}php-%{pecl_name}               < 8.4
%endif
Provides:       %{?scl_prefix}php-%{pecl_name}               = 1:%{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = 1:%{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
Use the OCI8 extension to access Oracle Database.

The extension is linked with Oracle client libraries %{oraclever}
(Oracle Instant Client).  For details, see Oracle's note
"Oracle Client / Server Interoperability Support" (ID 207303.1).

You must install libclntsh.so.%{oraclelib} to use this package,
provided by Oracle Instant Client RPM available from Oracle on:
https://www.oracle.com/database/technologies/instant-client/downloads.html

Documentation is at https://php.net/oci8

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
# don't install tests
sed -e 's/role="test"/role="src"/' \
    -e '/LICENSE/s/role="doc"/role="src"/' \
    -i package.xml

cd %{sources}
# Check reported version (phpinfo), as this is often broken
extver=$(sed -n '/#define PHP_OCI8_VERSION/{s/.* "//;s/".*$//;p}' php_oci8.h)
if test "x${extver}" != "x%{version}%{?versuffix}"; then
   : Error: Upstream version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

# Drop in the bit of configuration
cat > %{ini_name} << 'EOF'
; Enable %{summary}
extension = %{pecl_name}.so

; Connection: Enables privileged connections using external
; credentials (OCI_SYSOPER, OCI_SYSDBA)
; https://php.net/oci8.privileged-connect
;oci8.privileged_connect = Off

; Connection: The maximum number of persistent OCI8 connections per
; process. Using -1 means no limit.
; https://php.net/oci8.max-persistent
;oci8.max_persistent = -1

; Connection: The maximum number of seconds a process is allowed to
; maintain an idle persistent connection. Using -1 means idle
; persistent connections will be maintained forever.
; https://php.net/oci8.persistent-timeout
;oci8.persistent_timeout = -1

; Connection: The number of seconds that must pass before issuing a
; ping during oci_pconnect() to check the connection validity. When
; set to 0, each oci_pconnect() will cause a ping. Using -1 disables
; pings completely.
; https://php.net/oci8.ping-interval
;oci8.ping_interval = 60

; Connection: Set this to a user chosen connection class to be used
; for all pooled server requests with Oracle Database Resident
; Connection Pooling (DRCP).  To use DRCP, this value should be set to
; the same string for all web servers running the same application,
; the database pool must be configured, and the connection string must
; specify to use a pooled server.
;oci8.connection_class =

; High Availability: Using On lets PHP receive Fast Application
; Notification (FAN) events generated when a database node fails. The
; database must also be configured to post FAN events.
;oci8.events = Off

; Tuning: This option enables statement caching, and specifies how
; many statements to cache. Using 0 disables statement caching.
; https://php.net/oci8.statement-cache-size
;oci8.statement_cache_size = 20

; Tuning: Enables row prefetching and sets the default number of
; rows that will be fetched automatically after statement execution.
; https://php.net/oci8.default-prefetch
;oci8.default_prefetch = 100

; Tuning: Sets the amount of LOB data that is internally returned from
; Oracle Database when an Oracle LOB locator is initially retrieved as
; part of a query. Setting this can improve performance by reducing
; round-trips.
; https://php.net/oci8.prefetch-lob-size
; oci8.prefetch_lob_size = 0

; Compatibility. Using On means oci_close() will not close
; oci_connect() and oci_new_connect() connections.
; https://php.net/oci8.old-oci-close-semantics
;oci8.old_oci_close_semantics = Off
EOF

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif


%build
%{?dtsenable}

%if %{with_dtrace}
export PHP_DTRACE=yes
%endif

peclconf() {
%configure \
    --with-oci8=shared,instantclient,%{_root_prefix}/lib/oracle/%{oracledir}/client64/lib,%{oraclever} \
    --with-php-config=$1
}

cd %{sources}
%{__phpize}

cd ../NTS
peclconf %{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
peclconf %{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

# Install the ZTS stuff
%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%{php_ztsextdir}/%{pecl_name}.so
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%endif


%changelog
* Thu Jul 25 2024 Remi Collet <remi@remirepo.net> - 3.4.0-1
- update to 3.4.0
- use oracle client library version 23.5 on x86_64, 19.23 on aarch64
- build out of sources tree

* Thu Feb 20 2020 Remi Collet <remi@remirepo.net> - 2.2.0-3
- use oracle client library version 19.5

* Mon Aug 26 2019 Remi Collet <remi@remirepo.net> - 2.2.0-2
- use oracle client library version 19.3

* Mon Dec 10 2018 Remi Collet <remi@remirepo.net> - 2.2.0-1
- update to 2.2.0
- raise dependency on PHP 7.0
- switch to oracle client library 18.3

* Thu Sep 01 2016 Remi Collet <remi@fedoraproject.org> - 2.0.12-1
- Update to 2.0.12

* Mon Apr 18 2016 Remi Collet <remi@fedoraproject.org> - 2.0.11-1
- Update to 2.0.11

* Thu Mar 10 2016 Remi Collet <remi@fedoraproject.org> - 2.0.10-2
- adapt for F24
- fix license management

* Sat Dec 12 2015 Remi Collet <remi@fedoraproject.org> - 2.0.10-1
- Update to 2.0.10
- drop runtime dependency on pear, new scriptlets

* Mon Sep  1 2014 Remi Collet <remi@fedoraproject.org> - 2.0.8-2
- fix SCL build

* Fri Aug  1 2014 Remi Collet <remi@fedoraproject.org> - 2.0.8-1
- initial package, version 2.0.8
